==> smartgwtee-eval-5.1p.zip: com/smartgwt/logicalstructure/widgets/chart/FacetChartLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.chart;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class FacetChartLogicalStructure extends DrawPaneLogicalStructure {
    public String allowBubbleGradients;
    public String[] allowedChartTypes;
    public String autoRotateLabels;
    public String autoSortBubblePoints;
    public String axisEndValue;
    public String axisStartValue;
    public String backgroundBandProperties;
    public String bandedBackground;
    public String bandedStandardDeviations;
    public String barMargin;
    public String barProperties;
    public String bubbleHoverMaxDistance;
    public String bubbleProperties;
    public String canMoveAxes;
    public String canZoom;
    public String chartRectMargin;
    public String chartRectProperties;
    public String chartType;
    public String colorScaleMetric;
    public CellRecord[] dataAsCellRecordArray;
    public CellRecord dataAsCellRecord;
    public String dataAxisLabelProperties;
    public String[] dataColors;
    public String dataLabelProperties;
    public String dataLineProperties;
    public String dataLineType;
    public String dataMargin;
    public String dataOutlineProperties;
    public String dataPointProperties;
    public String dataPointSize;
    public String dataShapeProperties;
    public String decimalPrecision;
    public String discontinuousLines;
    public String doughnutHoleProperties;
    public String editProxyConstructor;
    public String errorBarWidth;
    public String errorLineProperties;
    public String expectedValueLineProperties;
    public String[] extraAxisMetrics;
    public MetricSettings[] extraAxisSettings;
    public String filled;
    public String gradationLabelProperties;
    public String gradationLineProperties;
    public String gradationTickMarkLength;
    public String gradationZeroLineProperties;
    public String highErrorMetric;
    public String hoverLabelPadding;
    public String hoverLabelProperties;
    public String hoverRectProperties;
    public String labelCollapseMode;
    public String legendItemPadding;
    public String legendLabelProperties;
    public String legendMargin;
    public String legendPadding;
    public String legendRectProperties;
    public String legendSwatchProperties;
    public String legendSwatchSize;
    public String legendTextPadding;
    public String logBase;
    public String logScale;
    public String logScalePointColor;
    public String logScalePointSize;
    public String lowErrorMetric;
    public String maxBarThickness;
    public String maxDataPointSize;
    public String minBarThickness;
    public String minDataPointSize;
    public String minDataSpreadPercent;
    public String minLabelGap;
    public String minXDataSpreadPercent;
    public String padChartRectByCornerRadius;
    public String pieBorderProperties;
    public String pieLabelAngleStart;
    public String pieLabelLineExtent;
    public String pieLabelLineProperties;
    public String pieRingBorderProperties;
    public String pieSliceProperties;
    public String pieStartAngle;
    public String pointColorLogBase;
    public String[] pointShapes;
    public String pointSizeGradations;
    public String pointSizeLogBase;
    public String[] pointSizeLogGradations;
    public String pointSizeMetric;
    public String printZoomChart;
    public String probabilityMetric;
    public String proportional;
    public String proportionalAxisLabel;
    public String radarBackgroundProperties;
    public String radialLabelOffset;
    public String regressionLineProperties;
    public String regressionLineType;
    public String regressionPolynomialDegree;
    public String rotateLabels;
    public String scaleEndColor;
    public String scaleStartColor;
    public String shadowProperties;
    public String showBubbleLegendPerShape;
    public String showChartRect;
    public String showColorScaleLegend;
    public String showDataAxisLabel;
    public String showDataLabels;
    public String showDataPoints;
    public String showDataValues;
    public String showDoughnut;
    public String showExpectedValueLine;
    public String showGradationsOverData;
    public String showInlineLabels;
    public String showLegend;
    public String showPointSizeLegend;
    public String showRadarGradationLabels;
    public String showRegressionLine;
    public String showScatterLines;
    public String showShadows;
    public String showStandardDeviationLines;
    public String showStatisticsOverData;
    public String showTitle;
    public String showValueAxisLabel;
    public String showValueOnHover;
    public String stacked;
    public String[] standardDeviationBandProperties;
    public String standardDeviationLineProperties;
    public String[] standardDeviations;
    public String styleName;
    public String tickMarkToValueAxisMargin;
    public String title;
    public String titleProperties;
    public String useAutoGradients;
    public String useLogGradations;
    public String useMultiplePointShapes;
    public String usePointSizeLogGradations;
    public String useSymmetricStandardDeviations;
    public String valueAxisLabelProperties;
    public String valueAxisMargin;
    public String valueLineProperties;
    public String valueProperty;
    public String valueTitle;
    public String xAxisEndValueAsString;
    public String xAxisMetric;
    public String xAxisStartValueAsString;
    public String yAxisMetric;
    public String zoomChartHeight;
    public String zoomChartProperties;
    public String zoomEndValue;
    public String zoomLogScale;
    public String zoomSelectionChartProperties;
    public String zoomShowSelection;
    public String zoomStartPosition;
    public String zoomStartValue;
}

==> smartgwtee-eval-13.1p.zip: com/smartgwt/logicalstructure/widgets/chart/FacetChartLogicalStructure.java <==
package com.smartgwt.logicalstructure.widgets.chart;
import com.smartgwt.client.core.*;
import com.smartgwt.client.rpc.*;
import com.smartgwt.client.i18n.*;
import com.smartgwt.client.event.*;
import com.smartgwt.client.util.*;
import com.smartgwt.client.util.workflow.*;
import com.smartgwt.client.util.workflow.Process; // required to override java.lang.Process
import com.smartgwt.client.util.tour.*;
import com.smartgwt.client.types.*;
import com.smartgwt.client.data.*;
import com.smartgwt.client.data.Record;
import com.smartgwt.client.data.fields.*;
import com.smartgwt.client.tools.*;
import com.smartgwt.client.widgets.*;
import com.smartgwt.client.widgets.calendar.*;
import com.smartgwt.client.widgets.chart.*;
import com.smartgwt.client.widgets.cube.*;
import com.smartgwt.client.widgets.drawing.*;
import com.smartgwt.client.widgets.form.*;
import com.smartgwt.client.widgets.form.fields.*;
import com.smartgwt.client.widgets.form.validator.*;
import com.smartgwt.client.widgets.grid.*;
import com.smartgwt.client.widgets.layout.*;
import com.smartgwt.client.widgets.menu.*;
import com.smartgwt.client.widgets.plugins.*;
import com.smartgwt.client.widgets.tab.*;
import com.smartgwt.client.widgets.tableview.*;
import com.smartgwt.client.widgets.tile.*;
import com.smartgwt.client.widgets.toolbar.*;
import com.smartgwt.client.widgets.tree.*;
import com.smartgwt.client.widgets.viewer.*;
import com.smartgwt.logicalstructure.core.*;
import com.smartgwt.logicalstructure.widgets.*;
import com.smartgwt.logicalstructure.widgets.form.*;
import com.smartgwt.logicalstructure.widgets.tile.*;
import com.smartgwt.logicalstructure.widgets.grid.*;
import com.smartgwt.logicalstructure.widgets.chart.*;
import com.smartgwt.logicalstructure.widgets.layout.*;
import com.smartgwt.logicalstructure.widgets.menu.*;
import com.smartgwt.logicalstructure.widgets.tab.*;
import com.smartgwt.logicalstructure.widgets.toolbar.*;
import com.smartgwt.logicalstructure.widgets.tree.*;
import com.smartgwt.logicalstructure.widgets.viewer.*;
import com.smartgwt.logicalstructure.widgets.calendar.*;
import com.smartgwt.logicalstructure.widgets.cube.*;
import com.smartgwt.logicalstructure.widgets.drawing.*;

public class FacetChartLogicalStructure extends DrawPaneLogicalStructure {
    public String allowBubbleGradients;
    public String[] allowedChartTypes;
    public String autoRotateLabels;
    public String autoScrollContent;
    public String autoScrollData;
    public String autoScrollDataApproach;
    public String autoSortBubblePoints;
    public String axisEndValue;
    public String axisStartValue;
    public String bandedBackground;
    public String bandedStandardDeviations;
    public String barMargin;
    public String brightenAllOnHover;
    public String brightenPercent;
    public String bubbleHoverMaxDistance;
    public String canMoveAxes;
    public String canZoom;
    public String centerLegend;
    public String centerTitle;
    public String chartRectMargin;
    public String chartType;
    public String colorScaleMetric;
    public CellRecord[] dataAsCellRecordArray;
    public CellRecord dataAsCellRecord;
    public String dataAxisLabelDelimiter;
    public String[] dataColors;
    public String dataFetchMode;
    public String dataLabelFacetsMargin;
    public String dataLabelToValueAxisMargin;
    public String dataLineType;
    public String dataMargin;
    public String dataPointSize;
    public Shadow dataValueHoverShadow;
    public String decimalPrecision;
    public String discontinuousLines;
    public String drawLegendBoundary;
    public String drawTitleBackground;
    public String drawTitleBoundary;
    public String editProxyConstructor;
    public String endValueMetric;
    public String errorBarWidth;
    public String extraAxisLabelAlign;
    public String[] extraAxisMetrics;
    public MetricSettings[] extraAxisSettings;
    public String[] facetFieldsAsStringArrayArray;
    public String filled;
    public String formatStringFacetValueIds;
    public String[] gradationGaps;
    public String gradationLabelPadding;
    public String gradationTickMarkLength;
    public String highErrorMetric;
    public String highlightDataValues;
    public String hoverLabelPadding;
    public String labelCollapseMode;
    public String legendAlign;
    public String legendItemPadding;
    public String legendMargin;
    public String legendPadding;
    public String legendRectHeight;
    public String legendSwatchSize;
    public String legendTextPadding;
    public String logBase;
    public String logScale;
    public String logScalePointColor;
    public String logScalePointSize;
    public String lowErrorMetric;
    public String[] majorTickGradations;
    public String[] majorTickTimeIntervals;
    public String matchBarChartDataLineColor;
    public String maxBarThickness;
    public String maxDataPointSize;
    public String maxDataZIndex;
    public String metricFacetId;
    public String minBarThickness;
    public String minChartHeight;
    public String minChartWidth;
    public String minContentHeight;
    public String minContentWidth;
    public String minDataPointSize;
    public String minDataSpreadPercent;
    public String minLabelGap;
    public String minorTickLength;
    public String minXDataSpreadPercent;
    public String[] otherAxisGradationGaps;
    public String[] otherAxisGradationTimes;
    public String otherAxisPixelsPerGradation;
    public String padChartRectByCornerRadius;
    public String pieLabelAngleStart;
    public String pieLabelLineExtent;
    public String pieStartAngle;
    public String pixelsPerGradation;
    public String pointColorLogBase;
    public String[] pointShapes;
    public String pointSizeGradations;
    public String pointSizeLogBase;
    public String[] pointSizeLogGradations;
    public String pointSizeMetric;
    public String printZoomChart;
    public String probabilityMetric;
    public String proportional;
    public String proportionalAxisLabel;
    public String radarRotateLabels;
    public String radialLabelOffset;
    public String regressionLineType;
    public String regressionPolynomialDegree;
    public String rotateDataValues;
    public String rotateLabels;
    public String scaleEndColor;
    public String scaleStartColor;
    public String showBubbleLegendPerShape;
    public String showChartRect;
    public String showColorScaleLegend;
    public String showDataAxisLabel;
    public String showDataLabels;
    public String showDataPoints;
    public String showDataValues;
    public String showDataValuesMode;
    public String showDetailFields;
    public String showDoughnut;
    public String showExpectedValueLine;
    public String showGradationsOverData;
    public String showInlineLabels;
    public String showLegend;
    public String showMinorTicks;
    public String showPointSizeLegend;
    public String showRadarGradationLabels;
    public String showRegressionLine;
    public String showScatterLines;
    public String showShadows;
    public String showStandardDeviationLines;
    public String showStatisticsOverData;
    public String showTitle;
    public String showValueAxisLabel;
    public String showValueOnHover;
    public String showXTicks;
    public String showYTicks;
    public String stacked;
    public String[] standardDeviations;
    public String styleName;
    public String tickLength;
    public String tickMarkToValueAxisMargin;
    public String title;
    public String titleAlign;
    public String titlePadding;
    public String titleRectHeight;
    public String useAutoGradients;
    public String useLogGradations;
    public String useMultiplePointShapes;
    public String usePointSizeLogGradations;
    public String useSymmetricStandardDeviations;
    public String valueAxisMargin;
    public String valueProperty;
    public String valueTitle;
    public String xAxisEndValueAsString;
    public String xAxisMetric;
    public String xAxisStartValueAsString;
    public String yAxisLabelAlign;
    public String yAxisLabelPadding;
    public String yAxisMetric;
    public String zIndexMetric;
    public String zoomChartHeight;
    public String zoomEndValue;
    public String zoomLogScale;
    public String zoomShowSelection;
    public String zoomStartPosition;
    public String zoomStartValue;
}
